Class: Aws::Pinpoint::Types::APNSChannelRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpoint/types.rb

Overview

Specifies the status and settings of the APNs (Apple Push Notification service) channel for an application.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bundle_idString

The bundle identifier that’s assigned to your iOS app. This identifier is used for APNs tokens.



274
275
276
277
278
279
280
281
282
283
284
285
# File 'lib/aws-sdk-pinpoint/types.rb', line 274

class APNSChannelRequest < Struct.new(
  :bundle_id,
  :certificate,
  :default_authentication_method,
  :enabled,
  :private_key,
  :team_id,
  :token_key,
  :token_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#certificateString

The APNs client certificate that you received from Apple, if you want Amazon Pinpoint to communicate with APNs by using an APNs certificate.



274
275
276
277
278
279
280
281
282
283
284
285
# File 'lib/aws-sdk-pinpoint/types.rb', line 274

class APNSChannelRequest < Struct.new(
  :bundle_id,
  :certificate,
  :default_authentication_method,
  :enabled,
  :private_key,
  :team_id,
  :token_key,
  :token_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#default_authentication_methodString

The default authentication method that you want Amazon Pinpoint to use when authenticating with APNs, key or certificate.



274
275
276
277
278
279
280
281
282
283
284
285
# File 'lib/aws-sdk-pinpoint/types.rb', line 274

class APNSChannelRequest < Struct.new(
  :bundle_id,
  :certificate,
  :default_authentication_method,
  :enabled,
  :private_key,
  :team_id,
  :token_key,
  :token_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#enabledBoolean

Specifies whether to enable the APNs channel for the application.



274
275
276
277
278
279
280
281
282
283
284
285
# File 'lib/aws-sdk-pinpoint/types.rb', line 274

class APNSChannelRequest < Struct.new(
  :bundle_id,
  :certificate,
  :default_authentication_method,
  :enabled,
  :private_key,
  :team_id,
  :token_key,
  :token_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#private_keyString

The private key for the APNs client certificate that you want Amazon Pinpoint to use to communicate with APNs.



274
275
276
277
278
279
280
281
282
283
284
285
# File 'lib/aws-sdk-pinpoint/types.rb', line 274

class APNSChannelRequest < Struct.new(
  :bundle_id,
  :certificate,
  :default_authentication_method,
  :enabled,
  :private_key,
  :team_id,
  :token_key,
  :token_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#team_idString

The identifier that’s assigned to your Apple developer account team. This identifier is used for APNs tokens.



274
275
276
277
278
279
280
281
282
283
284
285
# File 'lib/aws-sdk-pinpoint/types.rb', line 274

class APNSChannelRequest < Struct.new(
  :bundle_id,
  :certificate,
  :default_authentication_method,
  :enabled,
  :private_key,
  :team_id,
  :token_key,
  :token_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#token_keyString

The authentication key to use for APNs tokens.



274
275
276
277
278
279
280
281
282
283
284
285
# File 'lib/aws-sdk-pinpoint/types.rb', line 274

class APNSChannelRequest < Struct.new(
  :bundle_id,
  :certificate,
  :default_authentication_method,
  :enabled,
  :private_key,
  :team_id,
  :token_key,
  :token_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#token_key_idString

The key identifier that’s assigned to your APNs signing key, if you want Amazon Pinpoint to communicate with APNs by using APNs tokens.



274
275
276
277
278
279
280
281
282
283
284
285
# File 'lib/aws-sdk-pinpoint/types.rb', line 274

class APNSChannelRequest < Struct.new(
  :bundle_id,
  :certificate,
  :default_authentication_method,
  :enabled,
  :private_key,
  :team_id,
  :token_key,
  :token_key_id)
  SENSITIVE = []
  include Aws::Structure
end