Method: Aws::Pinpoint::Types::APNSMessage#substitutions

Defined in:
lib/aws-sdk-pinpoint/types.rb

#substitutionsHash<String,Array<String>>

The default message variables to use in the notification message. You can override these default variables with individual address variables.



581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
# File 'lib/aws-sdk-pinpoint/types.rb', line 581

class APNSMessage < Struct.new(
  :apns_push_type,
  :action,
  :badge,
  :body,
  :category,
  :collapse_id,
  :data,
  :media_url,
  :preferred_authentication_method,
  :priority,
  :raw_content,
  :silent_push,
  :sound,
  :substitutions,
  :thread_id,
  :time_to_live,
  :title,
  :url)
  SENSITIVE = []
  include Aws::Structure
end