Class: Aws::Pinpoint::Types::CampaignDateRangeKpiResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpoint/types.rb

Overview

Provides the results of a query that retrieved the data for a standard metric that applies to a campaign, and provides information about that query.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_idString

The unique identifier for the application that the metric applies to.

Returns:



2026
2027
2028
2029
2030
2031
2032
2033
2034
2035
2036
# File 'lib/aws-sdk-pinpoint/types.rb', line 2026

class CampaignDateRangeKpiResponse < Struct.new(
  :application_id,
  :campaign_id,
  :end_time,
  :kpi_name,
  :kpi_result,
  :next_token,
  :start_time)
  SENSITIVE = []
  include Aws::Structure
end

#campaign_idString

The unique identifier for the campaign that the metric applies to.

Returns:



2026
2027
2028
2029
2030
2031
2032
2033
2034
2035
2036
# File 'lib/aws-sdk-pinpoint/types.rb', line 2026

class CampaignDateRangeKpiResponse < Struct.new(
  :application_id,
  :campaign_id,
  :end_time,
  :kpi_name,
  :kpi_result,
  :next_token,
  :start_time)
  SENSITIVE = []
  include Aws::Structure
end

#end_timeTime

The last date and time of the date range that was used to filter the query results, in extended ISO 8601 format. The date range is inclusive.

Returns:



2026
2027
2028
2029
2030
2031
2032
2033
2034
2035
2036
# File 'lib/aws-sdk-pinpoint/types.rb', line 2026

class CampaignDateRangeKpiResponse < Struct.new(
  :application_id,
  :campaign_id,
  :end_time,
  :kpi_name,
  :kpi_result,
  :next_token,
  :start_time)
  SENSITIVE = []
  include Aws::Structure
end

#kpi_nameString

The name of the metric, also referred to as a *key performance indicator (KPI)*, that the data was retrieved for. This value describes the associated metric and consists of two or more terms, which are comprised of lowercase alphanumeric characters, separated by a hyphen. For a list of possible values, see the [Amazon Pinpoint Developer Guide].

[1]: docs.aws.amazon.com/pinpoint/latest/developerguide/analytics-standard-metrics.html

Returns:



2026
2027
2028
2029
2030
2031
2032
2033
2034
2035
2036
# File 'lib/aws-sdk-pinpoint/types.rb', line 2026

class CampaignDateRangeKpiResponse < Struct.new(
  :application_id,
  :campaign_id,
  :end_time,
  :kpi_name,
  :kpi_result,
  :next_token,
  :start_time)
  SENSITIVE = []
  include Aws::Structure
end

#kpi_resultTypes::BaseKpiResult

An array of objects that contains the results of the query. Each object contains the value for the metric and metadata about that value.

Returns:



2026
2027
2028
2029
2030
2031
2032
2033
2034
2035
2036
# File 'lib/aws-sdk-pinpoint/types.rb', line 2026

class CampaignDateRangeKpiResponse < Struct.new(
  :application_id,
  :campaign_id,
  :end_time,
  :kpi_name,
  :kpi_result,
  :next_token,
  :start_time)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The string to use in a subsequent request to get the next page of results in a paginated response. This value is null for the Campaign Metrics resource because the resource returns all results in a single page.

Returns:



2026
2027
2028
2029
2030
2031
2032
2033
2034
2035
2036
# File 'lib/aws-sdk-pinpoint/types.rb', line 2026

class CampaignDateRangeKpiResponse < Struct.new(
  :application_id,
  :campaign_id,
  :end_time,
  :kpi_name,
  :kpi_result,
  :next_token,
  :start_time)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

The first date and time of the date range that was used to filter the query results, in extended ISO 8601 format. The date range is inclusive.

Returns:



2026
2027
2028
2029
2030
2031
2032
2033
2034
2035
2036
# File 'lib/aws-sdk-pinpoint/types.rb', line 2026

class CampaignDateRangeKpiResponse < Struct.new(
  :application_id,
  :campaign_id,
  :end_time,
  :kpi_name,
  :kpi_result,
  :next_token,
  :start_time)
  SENSITIVE = []
  include Aws::Structure
end