Class: Aws::Pinpoint::Types::DefaultPushNotificationTemplate

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpoint/types.rb

Overview

Specifies the default settings and content for a message template that can be used in messages that are sent through a push notification channel.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionString

The action to occur if a recipient taps a push notification that’s based on the message template. Valid values are:

  • OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.

  • DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of the iOS and Android platforms.

  • URL - The default mobile browser on the recipient’s device opens and loads the web page at a URL that you specify.



3453
3454
3455
3456
3457
3458
3459
3460
3461
# File 'lib/aws-sdk-pinpoint/types.rb', line 3453

class DefaultPushNotificationTemplate < Struct.new(
  :action,
  :body,
  :sound,
  :title,
  :url)
  SENSITIVE = []
  include Aws::Structure
end

#bodyString

The message body to use in push notifications that are based on the message template.



3453
3454
3455
3456
3457
3458
3459
3460
3461
# File 'lib/aws-sdk-pinpoint/types.rb', line 3453

class DefaultPushNotificationTemplate < Struct.new(
  :action,
  :body,
  :sound,
  :title,
  :url)
  SENSITIVE = []
  include Aws::Structure
end

#soundString

The sound to play when a recipient receives a push notification that’s based on the message template. You can use the default stream or specify the file name of a sound resource that’s bundled in your app. On an Android platform, the sound file must reside in /res/raw/.

For an iOS platform, this value is the key for the name of a sound file in your app’s main bundle or the Library/Sounds folder in your app’s data container. If the sound file can’t be found or you specify default for the value, the system plays the default alert sound.



3453
3454
3455
3456
3457
3458
3459
3460
3461
# File 'lib/aws-sdk-pinpoint/types.rb', line 3453

class DefaultPushNotificationTemplate < Struct.new(
  :action,
  :body,
  :sound,
  :title,
  :url)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title to use in push notifications that are based on the message template. This title appears above the notification message on a recipient’s device.



3453
3454
3455
3456
3457
3458
3459
3460
3461
# File 'lib/aws-sdk-pinpoint/types.rb', line 3453

class DefaultPushNotificationTemplate < Struct.new(
  :action,
  :body,
  :sound,
  :title,
  :url)
  SENSITIVE = []
  include Aws::Structure
end

#urlString

The URL to open in a recipient’s default mobile browser, if a recipient taps a push notification that’s based on the message template and the value of the Action property is URL.



3453
3454
3455
3456
3457
3458
3459
3460
3461
# File 'lib/aws-sdk-pinpoint/types.rb', line 3453

class DefaultPushNotificationTemplate < Struct.new(
  :action,
  :body,
  :sound,
  :title,
  :url)
  SENSITIVE = []
  include Aws::Structure
end