Class: Aws::Pinpoint::Types::EmailChannelRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpoint/types.rb

Overview

Specifies the status and settings of the email channel for an application.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#configuration_setString

The [Amazon SES configuration set] that you want to apply to messages that you send through the channel.

[1]: docs.aws.amazon.com/ses/latest/APIReference/API_ConfigurationSet.html



4162
4163
4164
4165
4166
4167
4168
4169
4170
4171
# File 'lib/aws-sdk-pinpoint/types.rb', line 4162

class EmailChannelRequest < Struct.new(
  :configuration_set,
  :enabled,
  :from_address,
  :identity,
  :role_arn,
  :orchestration_sending_role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#enabledBoolean

Specifies whether to enable the email channel for the application.



4162
4163
4164
4165
4166
4167
4168
4169
4170
4171
# File 'lib/aws-sdk-pinpoint/types.rb', line 4162

class EmailChannelRequest < Struct.new(
  :configuration_set,
  :enabled,
  :from_address,
  :identity,
  :role_arn,
  :orchestration_sending_role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#from_addressString

The verified email address that you want to send email from when you send email through the channel.



4162
4163
4164
4165
4166
4167
4168
4169
4170
4171
# File 'lib/aws-sdk-pinpoint/types.rb', line 4162

class EmailChannelRequest < Struct.new(
  :configuration_set,
  :enabled,
  :from_address,
  :identity,
  :role_arn,
  :orchestration_sending_role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#identityString

The Amazon Resource Name (ARN) of the identity, verified with Amazon Simple Email Service (Amazon SES), that you want to use when you send email through the channel.



4162
4163
4164
4165
4166
4167
4168
4169
4170
4171
# File 'lib/aws-sdk-pinpoint/types.rb', line 4162

class EmailChannelRequest < Struct.new(
  :configuration_set,
  :enabled,
  :from_address,
  :identity,
  :role_arn,
  :orchestration_sending_role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#orchestration_sending_role_arnString

The ARN of an IAM role for Amazon Pinpoint to use to send email from your campaigns or journeys through Amazon SES.



4162
4163
4164
4165
4166
4167
4168
4169
4170
4171
# File 'lib/aws-sdk-pinpoint/types.rb', line 4162

class EmailChannelRequest < Struct.new(
  :configuration_set,
  :enabled,
  :from_address,
  :identity,
  :role_arn,
  :orchestration_sending_role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The ARN of the AWS Identity and Access Management (IAM) role that you want Amazon Pinpoint to use when it submits email-related event data for the channel.



4162
4163
4164
4165
4166
4167
4168
4169
4170
4171
# File 'lib/aws-sdk-pinpoint/types.rb', line 4162

class EmailChannelRequest < Struct.new(
  :configuration_set,
  :enabled,
  :from_address,
  :identity,
  :role_arn,
  :orchestration_sending_role_arn)
  SENSITIVE = []
  include Aws::Structure
end