Method: Aws::Pinpoint::Types::EndpointRequest#address

Defined in:
lib/aws-sdk-pinpoint/types.rb

#addressString

The destination address for messages or push notifications that you send to the endpoint. The address varies by channel. For a push-notification channel, use the token provided by the push notification service, such as an Apple Push Notification service (APNs) device token or a Firebase Cloud Messaging (FCM) registration token. For the SMS channel, use a phone number in E.164 format, such as +12065550100. For the email channel, use an email address.



4958
4959
4960
4961
4962
4963
4964
4965
4966
4967
4968
4969
4970
4971
4972
# File 'lib/aws-sdk-pinpoint/types.rb', line 4958

class EndpointRequest < Struct.new(
  :address,
  :attributes,
  :channel_type,
  :demographic,
  :effective_date,
  :endpoint_status,
  :location,
  :metrics,
  :opt_out,
  :request_id,
  :user)
  SENSITIVE = []
  include Aws::Structure
end