Method: Aws::Pinpoint::Types::EndpointSendConfiguration#raw_content

Defined in:
lib/aws-sdk-pinpoint/types.rb

#raw_contentString

The raw, JSON-formatted string to use as the payload for the message. If specified, this value overrides all other values for the message.

Returns:

  • (String)


5136
5137
5138
5139
5140
5141
5142
5143
5144
# File 'lib/aws-sdk-pinpoint/types.rb', line 5136

class EndpointSendConfiguration < Struct.new(
  :body_override,
  :context,
  :raw_content,
  :substitutions,
  :title_override)
  SENSITIVE = []
  include Aws::Structure
end