Method: Aws::Pinpoint::Types::GCMMessage#sound
- Defined in:
- lib/aws-sdk-pinpoint/types.rb
#sound ⇒ String
The sound to play when the recipient receives the push notification. You can use the default stream or specify the file name of a sound resource that’s bundled in your app. On an Android platform, the sound file must reside in /res/raw/.
5969 5970 5971 5972 5973 5974 5975 5976 5977 5978 5979 5980 5981 5982 5983 5984 5985 5986 5987 5988 5989 5990 |
# File 'lib/aws-sdk-pinpoint/types.rb', line 5969 class GCMMessage < Struct.new( :action, :body, :collapse_key, :data, :icon_reference, :image_icon_url, :image_url, :preferred_authentication_method, :priority, :raw_content, :restricted_package_name, :silent_push, :small_image_icon_url, :sound, :substitutions, :time_to_live, :title, :url) SENSITIVE = [] include Aws::Structure end |