Class: Aws::Pinpoint::Types::MessageResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpoint/types.rb

Overview

Provides information about the results of sending a message directly to an endpoint address.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#delivery_statusString

The delivery status of the message. Possible values are:

  • DUPLICATE - The endpoint address is a duplicate of another endpoint address. Amazon Pinpoint won’t attempt to send the message again.

  • OPT_OUT - The user who’s associated with the endpoint address has opted out of receiving messages from you. Amazon Pinpoint won’t attempt to send the message again.

  • PERMANENT_FAILURE - An error occurred when delivering the message to the endpoint address. Amazon Pinpoint won’t attempt to send the message again.

  • SUCCESSFUL - The message was successfully delivered to the endpoint address.

  • TEMPORARY_FAILURE - A temporary error occurred. Amazon Pinpoint won’t attempt to send the message again.

  • THROTTLED - Amazon Pinpoint throttled the operation to send the message to the endpoint address.

  • UNKNOWN_FAILURE - An unknown error occurred.



9559
9560
9561
9562
9563
9564
9565
9566
9567
# File 'lib/aws-sdk-pinpoint/types.rb', line 9559

class MessageResult < Struct.new(
  :delivery_status,
  :message_id,
  :status_code,
  :status_message,
  :updated_token)
  SENSITIVE = []
  include Aws::Structure
end

#message_idString

The unique identifier for the message that was sent.



9559
9560
9561
9562
9563
9564
9565
9566
9567
# File 'lib/aws-sdk-pinpoint/types.rb', line 9559

class MessageResult < Struct.new(
  :delivery_status,
  :message_id,
  :status_code,
  :status_message,
  :updated_token)
  SENSITIVE = []
  include Aws::Structure
end

#status_codeInteger

The downstream service status code for delivering the message.



9559
9560
9561
9562
9563
9564
9565
9566
9567
# File 'lib/aws-sdk-pinpoint/types.rb', line 9559

class MessageResult < Struct.new(
  :delivery_status,
  :message_id,
  :status_code,
  :status_message,
  :updated_token)
  SENSITIVE = []
  include Aws::Structure
end

#status_messageString

The status message for delivering the message.



9559
9560
9561
9562
9563
9564
9565
9566
9567
# File 'lib/aws-sdk-pinpoint/types.rb', line 9559

class MessageResult < Struct.new(
  :delivery_status,
  :message_id,
  :status_code,
  :status_message,
  :updated_token)
  SENSITIVE = []
  include Aws::Structure
end

#updated_tokenString

For push notifications that are sent through the GCM channel, specifies whether the endpoint’s device registration token was updated as part of delivering the message.



9559
9560
9561
9562
9563
9564
9565
9566
9567
# File 'lib/aws-sdk-pinpoint/types.rb', line 9559

class MessageResult < Struct.new(
  :delivery_status,
  :message_id,
  :status_code,
  :status_message,
  :updated_token)
  SENSITIVE = []
  include Aws::Structure
end