Method: Aws::Pinpoint::Types::MultiConditionalSplitActivity#evaluation_wait_time
- Defined in:
- lib/aws-sdk-pinpoint/types.rb
#evaluation_wait_time ⇒ Types::WaitTime
The amount of time to wait or the date and time when Amazon Pinpoint determines whether the conditions are met.
9665 9666 9667 9668 9669 9670 9671 |
# File 'lib/aws-sdk-pinpoint/types.rb', line 9665 class MultiConditionalSplitActivity < Struct.new( :branches, :default_activity, :evaluation_wait_time) SENSITIVE = [] include Aws::Structure end |