Method: Aws::Pinpoint::Types::Schedule#frequency

Defined in:
lib/aws-sdk-pinpoint/types.rb

#frequencyString

Specifies how often the campaign is sent or whether the campaign is sent in response to a specific event.

Returns:

  • (String)


11014
11015
11016
11017
11018
11019
11020
11021
11022
11023
11024
# File 'lib/aws-sdk-pinpoint/types.rb', line 11014

class Schedule < Struct.new(
  :end_time,
  :event_filter,
  :frequency,
  :is_local_time,
  :quiet_time,
  :start_time,
  :timezone)
  SENSITIVE = []
  include Aws::Structure
end