Method: Aws::Pinpoint::Types::Schedule#quiet_time
- Defined in:
- lib/aws-sdk-pinpoint/types.rb
#quiet_time ⇒ Types::QuietTime
The default quiet time for the campaign. Quiet time is a specific time range when a campaign doesn’t send messages to endpoints, if all the following conditions are met:
-
The EndpointDemographic.Timezone property of the endpoint is set to a valid value.
-
The current time in the endpoint’s time zone is later than or equal to the time specified by the QuietTime.Start property for the campaign.
-
The current time in the endpoint’s time zone is earlier than or equal to the time specified by the QuietTime.End property for the campaign.
If any of the preceding conditions isn’t met, the endpoint will receive messages from the campaign, even if quiet time is enabled.
11014 11015 11016 11017 11018 11019 11020 11021 11022 11023 11024 |
# File 'lib/aws-sdk-pinpoint/types.rb', line 11014 class Schedule < Struct.new( :end_time, :event_filter, :frequency, :is_local_time, :quiet_time, :start_time, :timezone) SENSITIVE = [] include Aws::Structure end |