Method: Aws::Pinpoint::Types::VoiceMessage#language_code

Defined in:
lib/aws-sdk-pinpoint/types.rb

#language_codeString

The code for the language to use when synthesizing the text of the message script. For a list of supported languages and the code for each one, see the [Amazon Polly Developer Guide].

[1]: docs.aws.amazon.com/polly/latest/dg/what-is.html

Returns:

  • (String)


13384
13385
13386
13387
13388
13389
13390
13391
13392
# File 'lib/aws-sdk-pinpoint/types.rb', line 13384

class VoiceMessage < Struct.new(
  :body,
  :language_code,
  :origination_number,
  :substitutions,
  :voice_id)
  SENSITIVE = []
  include Aws::Structure
end