Method: Aws::Pinpoint::Types::CreateRecommenderConfiguration#recommendations_per_message
- Defined in:
- lib/aws-sdk-pinpoint/types.rb
#recommendations_per_message ⇒ Integer
The number of recommended items to retrieve from the model for each endpoint or user, depending on the value for the RecommendationProviderIdType property. This number determines how many recommended items are available for use in message variables. The minimum value is 1. The maximum value is 5. The default value is 5.
To use multiple recommended items and custom attributes with message variables, you have to use an AWS Lambda function (RecommendationTransformerUri) to perform additional processing of recommendation data.
3020 3021 3022 3023 3024 3025 3026 3027 3028 3029 3030 3031 3032 |
# File 'lib/aws-sdk-pinpoint/types.rb', line 3020 class CreateRecommenderConfiguration < Struct.new( :attributes, :description, :name, :recommendation_provider_id_type, :recommendation_provider_role_arn, :recommendation_provider_uri, :recommendation_transformer_uri, :recommendations_display_name, :recommendations_per_message) SENSITIVE = [] include Aws::Structure end |