Method: Aws::Pinpoint::Types::GCMMessage#raw_content
- Defined in:
- lib/aws-sdk-pinpoint/types.rb
#raw_content ⇒ String
The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.
5969 5970 5971 5972 5973 5974 5975 5976 5977 5978 5979 5980 5981 5982 5983 5984 5985 5986 5987 5988 5989 5990 |
# File 'lib/aws-sdk-pinpoint/types.rb', line 5969 class GCMMessage < Struct.new( :action, :body, :collapse_key, :data, :icon_reference, :image_icon_url, :image_url, :preferred_authentication_method, :priority, :raw_content, :restricted_package_name, :silent_push, :small_image_icon_url, :sound, :substitutions, :time_to_live, :title, :url) SENSITIVE = [] include Aws::Structure end |