Method: Aws::Pinpoint::Types::RecommenderConfigurationResponse#recommendations_display_name
- Defined in:
- lib/aws-sdk-pinpoint/types.rb
#recommendations_display_name ⇒ String
The custom display name for the standard endpoint or user attribute (RecommendationItems) that temporarily stores recommended items for each endpoint or user, depending on the value for the RecommendationProviderIdType property. This name appears in the **Attribute finder** of the template editor on the Amazon Pinpoint console.
This value is null if the configuration doesn’t invoke an AWS Lambda function (RecommendationTransformerUri) to perform additional processing of recommendation data.
10474 10475 10476 10477 10478 10479 10480 10481 10482 10483 10484 10485 10486 10487 10488 10489 |
# File 'lib/aws-sdk-pinpoint/types.rb', line 10474 class RecommenderConfigurationResponse < Struct.new( :attributes, :creation_date, :description, :id, :last_modified_date, :name, :recommendation_provider_id_type, :recommendation_provider_role_arn, :recommendation_provider_uri, :recommendation_transformer_uri, :recommendations_display_name, :recommendations_per_message) SENSITIVE = [] include Aws::Structure end |