Method: Aws::Pinpoint::Types::SetDimension#values
- Defined in:
- lib/aws-sdk-pinpoint/types.rb
#values ⇒ Array<String>
The criteria values to use for the segment dimension. Depending on the value of the DimensionType property, endpoints are included or excluded from the segment if their values match the criteria values.
11691 11692 11693 11694 11695 11696 |
# File 'lib/aws-sdk-pinpoint/types.rb', line 11691 class SetDimension < Struct.new( :dimension_type, :values) SENSITIVE = [] include Aws::Structure end |