Method: Aws::Pinpoint::Types::SimpleEmail#text_part
- Defined in:
- lib/aws-sdk-pinpoint/types.rb
#text_part ⇒ Types::SimpleEmailPart
The body of the email message, in plain text format. We recommend using plain text format for email clients that don’t render HTML content and clients that are connected to high-latency networks, such as mobile devices.
11750 11751 11752 11753 11754 11755 11756 11757 |
# File 'lib/aws-sdk-pinpoint/types.rb', line 11750 class SimpleEmail < Struct.new( :html_part, :subject, :text_part, :headers) SENSITIVE = [] include Aws::Structure end |